#ifndef __EZMANAGERLIBRARY_H
#define __EZMANAGERLIBRARY_H

//"ezManager library(VC++ SLL) version 2.1C 19-Mar.-2022 by SOLLAE systems Co., LTD."

#define MUX_TYPE_T2S    0
#define MUX_TYPE_ATC    1
#define MUX_TYPE_COD    2
#define MUX_TYPE_U2S    3
#define MUX_TYPE_MOD    4

#define PASSWD_SIZE 10

#define MAX_COM_PORT 48

#define PID_CIE_H10     0x20 /* CIE-H10	*/
#define PID_CIE_M10     0x21 /* CIE-M10	*/
#define PID_CIE_H14     0x22 /* CIE-H14	*/
#define PID_CSE_M32     0x23 /* CSE-M32	*/
#define PID_CSE_H20     0x24 /* CSE-H20	*/
#define PID_CSE_H21     0x25 /* CSE-H21	*/
#define PID_CSE_M73     0x26 /* CSE-M73	*/
#define PID_CSW_H80     0x27 /* CSW-H80	*/
#define PID_CSW_M80     0x28 /* CSW-M80	*/
#define PID_CSE_H25     0x29 /* CSE-H25	*/
#define PID_CSE_M51     0x2a /* CSE-M51	*/
#define PID_CSE_M53     0x2b /* CSE-M53	*/
#define PID_CSE_H53	    0x2c /* CSE-H53	*/
#define PID_CSW_M83	    0x2d /* CSW-M83	*/
#define PID_CSW_M85	    0x2e /* CSW-M85	*/
#define PID_CSE_H55	    0x2f /* CSE-H55	*/
#define PID_CSC_HR2	    0x30 /* CSC-HR2	*/
#define PID_CSE_M24	    0x31 /* CSE-M24	*/
#define PID_CSC_HR3	    0x32 /* CSC-HR3	*/
#define PID_CSC_H64	    0x33 /* CSC-H64 */
#define PID_CIE_H12	    0x34 /* CIE-H12	*/
#define PID_CSW_H85	    0x35 /* CSW-H85	*/
#define PID_CSE_T32	    0x36 /* CSE-T32	*/
#define PID_CSE_M53NI   0x37 /* CSE-M53NI */
#define PID_CSE_T16     0x39 /* CSE-T16	*/
#define PID_CSE_T48     0x3a /* CSE-T48	*/
#define PID_CSE_H53A    0x3b /* CSE-H53A */
#define PID_CSW_M84     0x3c /* CSE-M84	*/
#define PID_CSE_M53N    0x3d /* CSE-M53N */
#define PID_CSE_H53N    0x3e /* CSE-H53N */
#define PID_CSE_H55N    0x3f /* CSE-H55N */
#define PID_IDIS_100    0x60 /* IDIS-100 */
#define PID_CSC_H61     0x61 /* CSC-H61 */
#define PID_CSC_H62     0x62 /* CSC-H62 */
#define PID_CSW_H85N    0x63 /* CSW-H85N */
#define PID_CSE_M53G    0x64 /* CSE-M53G */

#define EZTCP_SUCCESS				1
#define EZTCP_ERR					-1
#define EZTCP_ERR_PWD				-100
#define EZTCP_ERR_RES				-200
#define EZTCP_ERR_LOCAL_IP			-300
#define EZTCP_ERR_SUBNETMASK	    -301
#define EZTCP_ERR_IO_SCRIPT			-400
#define EZTCP_ERR_IO_ADDR			-500
#define EZTCP_ERR_LOCAL_PORT_0		-600
#define EZTCP_ERR_LOCAL_PORT_1		-601
#define EZTCP_ERR_LOCAL_PORT_2		-602
#define EZTCP_ERR_LOCAL_PORT_3		-603
#define EZTCP_ERR_LOCAL_PORT_4		-604
#define EZTCP_ERR_LOCAL_PORT_5		-605
#define EZTCP_ERR_LOCAL_PORT_6		-606
#define EZTCP_ERR_PRODUCT_MISMATCH	-700 /* product ID mismatch */
#define EZTCP_ERR_UNKNOWN			-800 /* Unknown Error */
#define EZTCP_ERR_NO_INFO			-900
#define EZTCP_ERR_NO_NETWORK		-903
#define EZTCP_ERR_FLASH_NOSPACE		-904
#define EZTCP_ERR_PWD_LENGTH		-905
#define EZTCP_ERR_PDB				-906
#define EZTCP_ERR_WRITE_LOCK		-907
#define EZTCP_ERR_USER_DEFINED_MAC	-908
#define EZTCP_ERR_NO_CERT	-909
#define EZTCP_ERR_FOPEN -910
#define EZTCP_ERR_READ_CERT -911
#define EZTCP_ERR_NO_RSA_KEY -912
#define EZTCP_ERR_READ_RSA_KEY -913
#define EZTCP_ERR_DSA_GENERATE_PARAMETERS -914
#define EZTCP_ERR_DSA_GENERATE_KEY -915

#define NI_MAXHOST	1025

#pragma comment(lib, "ezManagerLib.lib")
#pragma comment(lib, "iphlpapi.lib")
#pragma comment(lib, "ws2_32.lib")

struct eztcp_info
{
	unsigned char	mac_address[6];
	char			hostname[NI_MAXHOST];
	unsigned char	comment[65];
	int				env_status;
	char			product_name[32];
	int				search_method;
	int				search_port;
};

void Start_Library(int max_unit_number = 256);

void End_Library(void);

void 
	GetLibraryVersion(char *lib_version);

int get_eztcp_count(void);

int
	get_eztcp_info_by_index(int index, struct eztcp_info *out_eztcp_info);


int 
	EzTCP_Search(int udp_port_number, int *error);

int 
	EzTCP_Read(int search_method, unsigned char *mac_address, char *ip_addr, int udp_port_number, int *error);

int 
	EzTCP_Write(unsigned char *mac_address, char *password, int udp_port_number, int *error);

int 
	EzTCP_Initialize(unsigned char *mac_address, char *password, int udp_port_number, int *error);

int 
	EzTCP_ChangePassword(unsigned char *mac_address, char *current_pwd, char *new_pwd, int udp_port_number, int *error);

int 
	EzTCP_Status(unsigned char *mac_address, int udp_port_number, int *error);

int		
	get_status_string_length(void);

void	
	get_status_string(char *buf);

int		
	get_tcpip4_session_count(void);

int		
	get_tcpip6_session_count(void);

int		
	get_tcpip4_session_info(int session_number, char *out_session_info);

int		
	get_tcpip6_session_info(int session_number, char *out_session_info);

int 
	EzTCP_CloseTcpIp4(unsigned char *mac_address, int session_number, char *password, int *error); 

int 
	EzTCP_CloseTcpIp6(unsigned char *mac_address, int session_number, char *password, int *error); 

int 
	EzTCP_ReadCert(unsigned char *mac_address, int udp_port_number, int *error);

int 
	get_certificates_string_length(void);

void	
	get_certificates_string(char *buf);

int 
	EzTCP_WriteSelfSignedCertificates(unsigned char *mac_address, int rsa_key_length, char *country_code, char *state_name, char *locality_name, char *organization_name, char *organization_unit_name, char *common_name, char *email, int udp_port_number, int *error);

int
	EzTCP_WriteCertificates(unsigned char *mac_address, char *certificates_filepath, char *certificates_password, char *rsa_key_filepath, char *rsa_key_password, int udp_port_number, int *error);
//---------------------------------------------------------------------------------
// SET, GET, QUERY FUNCTIONS.
//
// QUERY FUNCTIONS
int 
	is_ip6(unsigned char* mac_address);

int	
	is_uart_rs232(unsigned char* mac_address, int uart_index);

int 
	is_uart_rs485(unsigned char* mac_address, int uart_index);

int 
	is_uart_rs422(unsigned char* mac_address, int uart_index);

int 
	is_uart_ttl(unsigned char* mac_address);

int 
	is_uart_8_databit_only(unsigned char* mac_address);

int   
	is_uart_7_and_8_databit_only(unsigned char* mac_address);

int 
	is_uart_one5_stopbit(unsigned char* mac_address);

int 
	is_uart_dtrdsr(unsigned char* mac_address);

int 
	is_uart_xonxoff(unsigned char* mac_address);

int 
	is_uart_tx_delay(unsigned char* mac_address);

int 
	is_uart_data_frame_interval(unsigned char* mac_address);

int 
	is_uart_separator(unsigned char* mac_address, int uart_index);

int 
	is_uart_tcp_nodelay(unsigned char* mac_address, int uart_index);

int 
	is_uart_rfc2217(unsigned char* mac_address, int uart_index);

int 
	is_uart_protocol(unsigned char* mac_address);

int 
	is_uart_tcp_server(unsigned char* mac_address, int uart_index);

int 
	is_uart_at_command(unsigned char* mac_address, int uart_index);

int 
	is_uart_tcp_client(unsigned char* mac_address, int uart_index);

int 
	is_uart_udp(unsigned char* mac_address, int uart_index);

int 
	is_uart_serial_modbus(unsigned char* mac_address, int uart_index);

int 
	is_uart_ssl(unsigned char* mac_address, int uart_index);

int	
	is_csc_hr2(unsigned char* mac_address);

int 
    is_rtu(unsigned char* mac_address);

int 
	is_io(unsigned char* mac_address);

int 
	is_io_output_automatic_initialize(unsigned char* mac_address);

int	
	is_io_email_notification(unsigned char* mac_address);

int	
	is_io_onoff_email_notification(unsigned char* mac_address);

int	
	is_wlan(unsigned char* mac_address);

int 
	is_wlan_soft_ap(unsigned char* mac_address);

int 
	is_wlan_antenna(unsigned char* mac_address);

int 
	is_wlan_phy_mode(unsigned char* mac_address);

int 
	is_wlan_background_scan(unsigned char* mac_address);

int 
	is_wlan_rsn(unsigned char* mac_address);

int 
	is_wlan_authentication_type(unsigned char* mac_address);

int 
	is_wlan_wpa_enterprise(unsigned char* mac_address);

int 
	is_send_mac_address(unsigned char* mac_address);

int 
	is_ssl(unsigned char* mac_address);

int 
	is_ssh(unsigned char* mac_address);

int 
	is_remote_debug(unsigned char* mac_address);

int 
	is_tcp_multi_connection(unsigned char* mac_address);

int 
	is_power_management(unsigned char* mac_address);

int 
	is_password(unsigned char* mac_address);

int 
	is_certificates(unsigned char* mac_address);

int 
	get_version(unsigned char* mac_address,	char * out_version);

int 
	get_arp(unsigned char* mac_address);

int 
	get_dhcp(unsigned char* mac_address);

int	
	get_dhcp_dns(unsigned char* mac_address);

int	
	get_wlan(unsigned char* mac_address);

int 
	get_pppoe(unsigned char* mac_address);

int 
	get_ip4_local_address(unsigned char* mac_address, char* out_address);

int 
	get_ip4_subnet_mask(unsigned char* mac_address, char* out_subnet_mask);

int 
	get_ip4_gateway_address(unsigned char* mac_address, char* out_address);

int 
	get_ip4_dns_address(unsigned char* mac_address, char* out_address);

int 
	get_pppoe_id(unsigned char* mac_address, char* out_pppoe_id);

int 
	get_pppoe_pwd(unsigned char* mac_address, char* out_pppoe_pwd);

int 
	get_ip6(unsigned char* mac_address);

int 
	get_ip6_eui_type(unsigned char* mac_address);

int 
	get_ip6_gua_type(unsigned char* mac_address);

int 
	get_ip6_local_address(unsigned char* mac_address, char* out_address);

int 
	get_ip6_subnet_prefix_length(unsigned char* mac_address, char* out_subnet_prefix_length);

int 
	get_ip6_gateway_address(unsigned char* mac_address, char* out_address);

int 
	get_ip6_dns_address(unsigned char* mac_address, char* out_address);

int 
	get_uart_count(unsigned char* mac_address);

int 
	get_uart_min_baudrate(unsigned char* mac_address);

int 
	get_uart_max_baudrate(unsigned char* mac_address, int uart_index);

int 
	get_uart_baudrate(unsigned char* mac_address, int uart_index);

int 
	get_uart_serial_type(unsigned char* mac_address, int uart_index);

int 
	get_uart_ttl(unsigned char* mac_address, int uart_index);

int 
	get_uart_tx_delay(unsigned char* mac_address, int uart_index);

int 
	get_uart_parity(unsigned char* mac_address, int uart_index);

int 
	get_uart_databit(unsigned char* mac_address, int uart_index);

int 
	get_uart_stopbit(unsigned char* mac_address, int uart_index);

int 
	get_uart_flow_control(unsigned char* mac_address, int uart_index);

int 
	get_uart_dtrdsr(unsigned char* mac_address, int uart_index);

int 
	get_uart_communication_mode(unsigned char* mac_address, int uart_index);

int 
	get_uart_peer_address(unsigned char* mac_address, int uart_index, char* out_address);

int 
	get_uart_peer_port(unsigned char* mac_address, int uart_index, char* out_port);

int 
	get_uart_local_port(unsigned char* mac_address, int uart_index, char* out_port);

int 
	get_uart_cod_tcp_server(unsigned char* mac_address, int uart_index);

int 
	get_uart_watermark(unsigned char* mac_address, int uart_index, char* out_watermark);

int 
	get_uart_timeout(unsigned char* mac_address, int uart_index, char* out_timeout);

int 
	get_uart_data_frame_interval(unsigned char* mac_address, int uart_index, char* out_data_frame_interval);

int 
	get_uart_separator_length(unsigned char* mac_address, int uart_index);

int 
	get_uart_separator_type(unsigned char* mac_address, int uart_index);

int 
	get_uart_separator(unsigned char* mac_address, int uart_index, int separator_index, char* out_separator);

int 
	get_uart_tcp_nodelay(unsigned char* mac_address, int uart_index);

int 
	get_uart_rfc2217(unsigned char* mac_address, int uart_index);

int  
	get_uart_protocol(unsigned char* mac_address, int uart_index);

int 
	get_csc_hr2_communication_mode(unsigned char* mac_address);

int 
	get_csc_hr2_id(unsigned char* mac_address, char* out_id);

int 
	get_csc_hr2_network_timeout(unsigned char* mac_address, char* out_timeout);

int 
	get_csc_hr2_network_threshold(unsigned char* mac_address, char* out_threshold);

int 
	get_csc_hr2_server_timeout(unsigned char* mac_address, char* out_timeout);

int 
	get_csc_hr2_server_threshold(unsigned char* mac_address, char* out_threshold);

int
	get_csc_hr2_check_port(unsigned char* mac_address, char* out_check_port);

int 
	get_csc_hr2_first_server_address(unsigned char* mac_address, char* out_address);

int 
	get_csc_hr2_first_server_port(unsigned char* mac_address, char* out_port);

int 
	get_csc_hr2_second_server_address(unsigned char* mac_address, char* out_address);

int 
	get_csc_hr2_second_server_port(unsigned char* mac_address, char* out_port);

int  
    get_rtu_first_server_address(unsigned char* mac_address, char* out_address);

int  
    get_rtu_second_server_address(unsigned char* mac_address, char* out_address);

int  
    get_rtu_first_server_port(unsigned char* mac_address, char* out_port);

int  
    get_rtu_second_server_port(unsigned char* mac_address, char* out_port);

int  
    get_rtu_first_check_port(unsigned char* mac_address, char* out_check_port);

int  
    get_rtu_second_check_port(unsigned char* mac_address, char* out_check_port);

int  
    get_rtu_server_timeout(unsigned char* mac_address, char* out_timeout);

int  
    get_rtu_server_threshold(unsigned char* mac_address, char* out_threshold);

int  
    get_rtu_communication_mode(unsigned char* mac_address);

int 
    get_rtu_tcp_nodelay(unsigned char* mac_address);

int  
    get_rtu_protocol(unsigned char* mac_address);

int  
    get_rtu_id(unsigned char* mac_address, char* out_rtu_id);

int 
	get_io_http(unsigned char* mac_address);

int 
	get_io_http_port(unsigned char* mac_address, char* out_http_port);

int 
	get_io_html_size(unsigned char* mac_address);

int 
	get_io_modbus(unsigned char* mac_address);

int 
	get_io_input_notification(unsigned char* mac_address);

int  
	get_io_output_automatic_initialize(unsigned char* mac_address);

int 
	get_io_modbus_type(unsigned char* mac_address);

int 
	get_io_unit_id(unsigned char* mac_address, char* out_unit_id);

int 
	get_io_input_address(unsigned char* mac_address, char* out_address);

int 
	get_io_output_address(unsigned char* mac_address, char* out_address);

int 
	get_io_poll_interval(unsigned char* mac_address, char* out_poll_interval);

int 
	get_io_slave_control_type(unsigned char* mac_address);

int 
	get_io_master_control_type(unsigned char* mac_address);

int 
	get_io_tcp_type(unsigned char* mac_address);

int 
	get_io_multi_connection_number(unsigned char* mac_address);

int 
	get_io_modbus_peer_address(unsigned char* mac_address, char* out_address);

int 
	get_io_modbus_peer_port(unsigned char* mac_address, char* out_port);

int 
	get_io_modbus_local_port(unsigned char* mac_address, char* out_port);

int 
	get_io_output_number(unsigned char* mac_address);

int 
	get_io_input_number(unsigned char* mac_address);

int  
	get_io_event_notification(unsigned char* mac_address);

int   
	get_event_notification_email(unsigned char* mac_address, char* out_email);

int  
	get_io_event_notification_port(unsigned char* mac_address, int port_flag, int port_index);

int 
	get_io_input_valid_time(unsigned char* mac_address, int port_index, char* out_input_valid_time);

int 
	get_io_macro_type(unsigned char* mac_address);

int 
	get_io_macro(unsigned char* mac_address);

int 
	get_io_port_macro(unsigned char* mac_address, int port_index);

int 
	get_io_macro_text(unsigned char* mac_address, int port_index, char* out_macro_text);

int 
	get_io_output_delay(unsigned char* mac_address, int port_index, char* out_output_delay);

int 
	get_io_output_initial_state(unsigned char* mac_address, int port_index);

int 
	get_io_comment(unsigned char* mac_address, int port_flag, int port_index, char* out_comment);

int 
	get_wlan_type(unsigned char* mac_address);

int 
	get_wlan_channel(unsigned char* mac_address);

int 
	get_wlan_ssid(unsigned char* mac_address, char* out_ssid);

int 
	get_wlan_antenna(unsigned char* mac_address);

int 
	get_wlan_phy_mode(unsigned char* mac_address);

int 
	get_wlan_short_preamble(unsigned char* mac_address);

int 
	get_wlan_short_slot(unsigned char* mac_address);

int 
	get_wlan_cts_protection(unsigned char* mac_address);

int 
	get_wlan_background_scan(unsigned char* mac_address);

int 
	get_wlan_encryption_type(unsigned char* mac_address);

int 
	get_wlan_authentication_type(unsigned char* mac_address);

int 
	get_wlan_wpa_enterprise(unsigned char* mac_address);

int 
	get_wlan_wpa_enterprise_id(unsigned char* mac_address, char* out_enterprise_id);

int 
	get_wlan_wpa_enterprise_pwd(unsigned char* mac_address, char* out_enterprise_pwd);

int 
	get_wlan_wep_key_length(unsigned char* mac_address);

int 
	get_wlan_wep_key_index(unsigned char* mac_address);

int 
	get_wlan_wep_key_data_type(unsigned char* mac_address, int wep_key_index);

int 
	get_wlan_wep_key(unsigned char* mac_address, char* out_wep_key);

int 
	get_wlan_max_wpa_passphrase_length(unsigned char* mac_address);

int 
	get_wlan_wpa_passphrase(unsigned char* mac_address, char* out_wpa_passphrase);

int 
	get_wlan_shared_key(unsigned char* mac_address, char* out_shared_key);

int 
	get_telnet(unsigned char* mac_address);

int 
	get_send_mac_address(unsigned char* mac_address);

int 
	get_ssl(unsigned char* mac_address);

int 
	get_uart_ssl(unsigned char* mac_address, int uart_index);

int 
	get_ssh(unsigned char* mac_address);

int 
	get_ip4_address_search(unsigned char* mac_address);

int 
	get_remote_debug(unsigned char* mac_address);

int 
	get_tcp_multi_connection(unsigned char* mac_address);

int 
	get_power_management(unsigned char* mac_address);

int 
	get_comment(unsigned char* mac_address, char* out_comment);

int 
	get_allowed_ezmanager(unsigned char* mac_address);

int 
	get_allowed_mac_address(unsigned char* mac_address, int mac_index, char* out_mac_address);

int 
	get_allowed_ip4_address(unsigned char* mac_address, char* out_address);

int 
	get_allowed_ip4_network_mask_type(unsigned char* mac_address);

int 
	get_allowed_ip6_address(unsigned char* mac_address, char* out_address);

int 
	get_allowed_ip6_subnet_prefix_length(unsigned char* mac_address, char* out_subnet_prefix_length);

int 
	get_ip4_change_notification_type(unsigned char* mac_address);

int 
	get_ip4_change_notification_data_type(unsigned char* mac_address);

int 
	get_ip4_change_notification_interval(unsigned char* mac_address, char* out_interval);

int 
	get_ip4_change_notification_peer_port(unsigned char* mac_address, char* out_port);

int 
	get_ip4_change_notification_peer_address(unsigned char* mac_address, char* out_address);

int 
	get_ip4_change_notification_ddns_id(unsigned char* mac_address, char* out_ddns_id);

int 
	get_ip4_change_notification_ddns_pwd(unsigned char* mac_address, char* out_ddbs_pwd);



int 
	set_arp(unsigned char* mac_address, int onoff);

int 
	set_dhcp(unsigned char* mac_address, int onoff);

int 
	set_dhcp_dns(unsigned char* mac_address, int onoff);

int 
	set_wlan(unsigned char* mac_address, int onoff); // FOR PHPoC

int 
	set_pppoe(unsigned char* mac_address, int onoff);

int 
	set_ip4_local_address(unsigned char* mac_address, char* ip4_local_address);

int 
	set_ip4_subnet_mask(unsigned char* mac_address, char* ip4_subnet_mask);

int 
	set_ip4_gateway_address(unsigned char* mac_address, char* ip4_gateway_address);

int 
	set_ip4_dns_address(unsigned char* mac_address, char* ip4_dns_address);

int 
	set_pppoe_id(unsigned char* mac_address, char* pppoe_id);

int 
	set_pppoe_pwd(unsigned char* mac_address, char* pppoe_pwd);

int 
	set_ip6(unsigned char* mac_address, int onoff);

int 
	set_ip6_gua_type(unsigned char* mac_address, int gua_type);

int 
	set_ip6_eui_type(unsigned char* mac_address, int eui_type);

int 
	set_ip6_local_address(unsigned char* mac_address, char* ip6_local_address);

int 
	set_ip6_subnet_prefix_length(unsigned char* mac_address, int ip6_subnet_prefix_length);

int 
	set_ip6_gateway_address(unsigned char* mac_address, char* ip6_gateway_address);

int 
	set_ip6_dns_address(unsigned char* mac_address, char* ip6_dns_address);

int 
	set_uart_serial_type(unsigned char* mac_address, int uart_index, int serial_type);

int 
	set_uart_ttl(unsigned char* mac_address, int uart_index, int onoff);

int 
	set_uart_baudrate(unsigned char* mac_address, int uart_index, int baudrate);

int 
	set_uart_parity(unsigned char* mac_address, int uart_index, int parity);

int 
	set_uart_databit(unsigned char* mac_address, int uart_index, int databit);

int 
	set_uart_stopbit(unsigned char* mac_address, int uart_index, int stopbit);

int 
	set_uart_flow_control(unsigned char* mac_address, int uart_index,  int flow_control);

int 
	set_uart_dtrdsr(unsigned char* mac_address, int uart_index, int onoff);

int 
	set_uart_tx_delay(unsigned char* mac_address, int uart_index, int tx_delay);

int 
	set_uart_communication_mode(unsigned char* mac_address, int uart_index, int communication_mode);

int 
	set_uart_peer_address(unsigned char* mac_address, int uart_index, char* peer_address);

int 
	set_uart_peer_port(unsigned char* mac_address, int uart_index, int peer_port);

int 
	set_uart_local_port(unsigned char* mac_address, int uart_index, int local_port);

int 
	set_uart_cod_tcp_server(unsigned char* mac_address, int uart_index, int onoff);

int 
	set_uart_watermark(unsigned char* mac_address, int uart_index, int watermark);

int 
	set_uart_timeout(unsigned char* mac_address, int uart_index, int timeout);

int 
	set_uart_data_frame_interval(unsigned char* mac_address, int uart_index, int data_frame_interval);

int 
	set_uart_separator_length(unsigned char* mac_address, int uart_index, int separator_length);

int 
	set_uart_separator_type(unsigned char* mac_address, int uart_index, int separator_type);

int 
	set_uart_separator(unsigned char* mac_address, int uart_index, int separator_index, char* separator);

int 
	set_uart_tcp_nodelay(unsigned char* mac_address, int uart_index, int onoff);

int 
	set_uart_rfc2217(unsigned char* mac_address, int uart_index, int onoff);

int 
	set_uart_protocol(unsigned char* mac_address, int uart_index, int uart_protocol);

int 
	set_csc_hr2_communication_mode(unsigned char* mac_address, int communication_mode);

int 
	set_csc_hr2_id(unsigned char* mac_address, char* csc_hr2_id);

int 
	set_csc_hr2_network_timeout(unsigned char* mac_address, int timeout);

int 
	set_csc_hr2_network_threshold(unsigned char* mac_address, int threshold);

int 
	set_csc_hr2_server_timeout(unsigned char* mac_address, int timeout);

int 
	set_csc_hr2_server_threshold(unsigned char* mac_address, int threshold);

int 
	set_csc_hr2_check_port(unsigned char* mac_address, int check_port);

int 
	set_csc_hr2_first_server_address(unsigned char* mac_address, char* server_address);

int 
	set_csc_hr2_first_server_port(unsigned char* mac_address, int server_port);

int 
	set_csc_hr2_second_server_address(unsigned char* mac_address, char* server_address);

int 
	set_csc_hr2_second_server_port(unsigned char* mac_address, int server_port);

int  
    set_rtu_first_server_address(unsigned char* mac_address, char* server_address);

int  
    set_rtu_second_server_address(unsigned char* mac_address, char* server_address);

int  
    set_rtu_first_server_port(unsigned char* mac_address, int server_port);

int  
    set_rtu_second_server_port(unsigned char* mac_address, int server_port);

int  
    set_rtu_first_check_port(unsigned char* mac_address, int check_port);

int  
    set_rtu_second_check_port(unsigned char* mac_address, int check_port);

int  
    set_rtu_server_timeout(unsigned char* mac_address, int timeout);

int  
    set_rtu_server_threshold(unsigned char* mac_address, int threshold);

int  
    set_rtu_communication_mode(unsigned char* mac_address, int communication_mode);

int 
    set_rtu_tcp_nodelay(unsigned char* mac_address, int onoff);

int  
    set_rtu_protocol(unsigned char* mac_address, int protocol);

int  
    set_rtu_id(unsigned char* mac_address, char* rtu_id);

int 
	set_io_http(unsigned char* mac_address, int onoff);

int 
	set_io_http_port(unsigned char* mac_address, int http_port);

int 
	set_io_html_size(unsigned char* mac_address, int html_size);

int 
	set_io_modbus(unsigned char* mac_address, int onoff);

int 
	set_io_input_notification(unsigned char* mac_address, int onoff);

int 
	set_io_output_automatic_initialize(unsigned char* mac_address, int onoff);

int 
	set_io_modbus_type(unsigned char* mac_address, int modbus_type);

int 
	set_io_unit_id(unsigned char* mac_address, int unit_id);

int 
	set_io_input_address(unsigned char* mac_address, int input_address);

int 
	set_io_output_address(unsigned char* mac_address, int output_address);

int 
	set_io_poll_interval(unsigned char* mac_address, int poll_interval);

int 
	set_io_slave_control_type(unsigned char* mac_address, int slave_control_type);

int 
	set_io_master_control_type(unsigned char* mac_address, int master_control_type);

int 
	set_io_tcp_type(unsigned char* mac_address, int tcp_type);

int 
	set_io_multi_connection_number(unsigned char* mac_address, int number);

int 
	set_io_modbus_peer_address(unsigned char* mac_address, char* peer_address);

int 
	set_io_modbus_peer_port(unsigned char* mac_address, int peer_port);

int 
	set_io_modbus_local_port(unsigned char* mac_address, int local_port);

int 
	set_io_event_notification(unsigned char* mac_address, int onoff);

int 
	set_event_notification_email(unsigned char* mac_address, char* email);

int 
	set_io_event_notification_port(unsigned char* mac_address, int port_flag, int port_index, int onoff, int trigger_type = 1);

int 
	set_io_input_valid_time(unsigned char* mac_address, int port_index, int input_valid_time);

int 
	set_io_macro(unsigned char* mac_address, int onoff);

int 
	set_io_port_macro(unsigned char* mac_address, int port_index, int onoff);

int 
	set_io_macro_text(unsigned char* mac_address, int port_index, char* macro_text);

int 
	set_io_output_delay(unsigned char* mac_address, int port_index, int output_delay);

int 
	set_io_output_initial_state(unsigned char* mac_address, int port_index, int onoff);

int 
	set_io_comment(unsigned char* mac_address, int port_flag, int port_index, char* comment);

int 
	set_wlan_type(unsigned char* mac_address, int wlan_type);

int 
	set_wlan_channel(unsigned char* mac_address, int channel);

int 
	set_wlan_ssid(unsigned char* mac_address, char* ssid);

int 
	set_wlan_antenna(unsigned char* mac_address, int antenna_type);

int 
	set_wlan_phy_mode(unsigned char* mac_address, int phy_mode);

int 
	set_wlan_short_preamble(unsigned char* mac_address, int onoff);

int 
	set_wlan_short_slot(unsigned char* mac_address, int onoff);

int 
	set_wlan_cts_protection(unsigned char* mac_address, int onoff);

int 
	set_wlan_background_scan(unsigned char* mac_address, int onoff);

int 
	set_wlan_encryption_type(unsigned char* mac_address, int encryption_type);

int 
	set_wlan_authentication_type(unsigned char* mac_address, int authentication_type);

int 
	set_wlan_wep_key_length(unsigned char* mac_address, int wep_key_length);

int 
	set_wlan_wep_key_index(unsigned char* mac_address, int wep_key_index);

int 
	set_wlan_wep_key_data_type(unsigned char* mac_address, int wep_key_data_type);

int 
	set_wlan_wep_key(unsigned char* mac_address, char* wep_key);

int 
	set_wlan_wpa_passphrase(unsigned char* mac_address, char* wpa_pp);

int 
	set_wlan_shared_key(unsigned char* mac_address, char* shared_key);

int 
	set_wlan_wpa_enterprise(unsigned char* mac_address, int enterprise_type);

int 
	set_wlan_wpa_enterprise_id(unsigned char* mac_address, char* enterprise_id);

int 
	set_wlan_wpa_enterprise_pwd(unsigned char* mac_address, char* enterprise_pwd);

int 
	set_telnet(unsigned char* mac_address, int onoff);

int 
	set_send_mac_address(unsigned char* mac_address, int onoff);

int 
	set_ssl(unsigned char* mac_address, int onoff);

int 
	set_uart_ssl(unsigned char* mac_address, int uart_index, int onoff);

int 
	set_ssh(unsigned char* mac_address, int onoff);

int 
	set_ip4_address_search(unsigned char* mac_address, int onoff);

int 
	set_remote_debug(unsigned char* mac_address, int onoff);

int 
	set_tcp_multi_connection(unsigned char* mac_address, int onoff);

int 
	set_power_management(unsigned char* mac_address, int onoff);

int 
	set_comment(unsigned char* mac_address, char* comment);

int 
	set_allowed_mac_address(unsigned char* mac_address, int index, char* in_mac_address);

int 
	set_allowed_ip4_address(unsigned char* mac_address, char* ip4_address);

int 
	set_allowed_ip4_network_mask_type(unsigned char* mac_address, int network_mask_type);

int 
	set_allowed_ezmanager(unsigned char* mac_address, int onoff);

int 
	set_allowed_ip6_address(unsigned char* mac_address, char* ip6_address);


int 
	set_allowed_ip6_subnet_prefix_length(unsigned char* mac_address, int subnet_prefix_length);

int 
	set_ip4_change_notification_type(unsigned char* mac_address, int notification_type);

int 
	set_ip4_change_notification_data_type(unsigned char* mac_address, int data_type);

int 
	set_ip4_change_notification_interval(unsigned char* mac_address, int interval);

int 
	set_ip4_change_notification_peer_port(unsigned char* mac_address, int port);

int 
	set_ip4_change_notification_peer_address(unsigned char* mac_address, char* host);

int 
	set_ip4_change_notification_ddns_id(unsigned char* mac_address, char* ddns_id);

int 
	set_ip4_change_notification_ddns_pwd(unsigned char* mac_address, char* ddns_pwd);

#endif
